@@ -66,7 +66,7 @@ uploadStock <- function(info, fishdata, verbose = FALSE) {
     message("\tResults: http://", datsu_resp$ScreenResultURL)
 
   if (datsu_resp$NumberOfErrors > 0) {
-    stop(" Errors were found in the upload.  See\n\t http://", datsu_resp$ScreenResultURL, "\n\tfor details")
+    warning(" Errors were found in the upload.  See\n\t http://", datsu_resp$ScreenResultURL, "\n\tfor details")
   }
 
   # call webservice
